@@ -133,6 +133,16 @@ multiple_tag_separator = "__"
                                          multiple_tag_separator = "_&_"   # this is different from the one defined above to prevent (!) separating multiple entries in the same image: Species will be something like "Leopard Cat__Malay Badger"
         )
 
+        # if images in station contain no metadata species tags, skip that station
+        if(class(metadata.tmp) != "data.frame"){
+          if(metadata.tmp == "found no species tag") {
+            warning(paste(dirs_short[i], ":   metadataSpeciesTag '", metadataSpeciesTag, "' not found in image metadata tag 'HierarchicalSubject'. Skipping", sep = ""), call. = FALSE, immediate. = TRUE)
+          } else {
+            warning(paste(dirs_short[i], ":   error in species tag extraction. Skipping. Please report", sep = ""), call. = FALSE, immediate. = TRUE)
+          }
+          next
+        }
+      
         # assign camera ID
         if(hasCameraFolders == TRUE){
           if(IDfrom == "directory"){
